@@ -1,7 +1,7 @@
 /*
  * Common environment for most program functions
  *
- * Copyright (C) 2003--2007  Enrico Zini <enrico@debian.org>
+ * Copyright (C) 2003--2008  Enrico Zini <enrico@debian.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -129,7 +129,7 @@ public:
 		// Find out the configuration file to use
 		if (opts.hasNext())
 			configFile = opts.next();
-		else if (opts.configfile->boolValue())
+		else if (opts.configfile->isSet())
 			configFile = opts.configfile->stringValue();
 
 		// Find out the default profile name
