@@ -4,7 +4,7 @@
 /*
  * Parser for standard guessnet configuration file
  *
- * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
+ * Copyright (C) 2003--2007  Enrico Zini <enrico@debian.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,13 +21,17 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "Parser.h"
+#include "parser.h"
 #include <stdio.h>
 
+namespace scanner {
+class Consumer;
+}
+
 class GuessnetParser
 {
 public:
-	static void parse(FILE* in, ScanConsumer& sc);
+	static void parse(FILE* in);
 };
 
 // vim:set ts=4 sw=4:
