@@ -21,13 +21,22 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "Parser.h"
+#include "parser.h"
 #include <stdio.h>
 
+/**
+ * Base stanza filter, to decide what we want and what we don't
+ */
+struct IfaceFilter
+{
+	virtual ~IfaceFilter() {}
+	virtual bool operator()(const std::string& name) const { return true; }
+};
+
 class IfaceParser
 {
 public:
-	static void parse(FILE* in, ScanConsumer& sc);
+	static void parse(FILE* in, const IfaceFilter& filter = IfaceFilter());
 };
 
 // vim:set ts=4 sw=4:
