@@ -1,6 +1,7 @@
 #include "Environment.h"
 #include "IFace.h"
-#include "NetWatcher.h"
+#include "util/netwatcher.h"
+#include "util/output.h"
 
 #include <stdio.h>
 
@@ -8,6 +9,8 @@ extern "C" {
 #include <libnet.h>
 }
 
+using namespace util;
+
 class PacketPrinter : public PacketListener
 {
 public:
@@ -37,23 +40,17 @@ int main(int argc, char* argv[])
 	try {
 		wibble::exception::InstallUnexpected installUnexpected;
 
+		NetWatcher::configure(argv[1]);
+
 		IFace iface(argv[1]);
 		if_params ifp = iface.getConfiguration();
 		printConfig("Initial", iface);
 
-		{
-			fprintf(stderr, "\t\tInitializing net watcher...\n");
-			NetWatcher watcher(argv[1]);
-			printConfig("Post-Inittest", iface);
-		}
-
-		fprintf(stderr, "\t\tInitializing net watcher...\n");
-		NetWatcher watcher(argv[1]);
-		printConfig("Post-NS", iface);
-
 		PacketPrinter pp;
-		watcher.addARPListener(&pp);
+		NetWatcher::get().addARPListener(&pp);
 		//watcher.addEthernetListener(&pp);
+		
+		Starter::get().start();
 
 		sleep(20);
 		
